@@ -5,7 +5,7 @@ import functools
 
 from tornado.ioloop import IOLoop
 import kola
-from kola.utils import safe_call
+from kola import safe_call
 
 
 class Blueprint(kola.Blueprint):
